@@ -76,6 +76,7 @@ from .constants import (
     PIL_TO_MIME,
     MIME_TO_PIL,
     REGEX_PREFIX,
+    REGEX_FILE_ID,
     LOG_FORMAT,
     LOG_TIMEFMT)
 
@@ -117,11 +118,13 @@ from .introspect import (
     membername)
 
 from .logging import (
-    logging,
-    getLogger,
+    disableLogging,
     getLevelName,
+    getLogger,
     initLogging,
-    setOverrideLogLevel)
+    logging,
+    setOverrideLogLevel,
+    )
 
 from .os import (
     abspath,
