@@ -7,6 +7,7 @@ __all__ = [
     'unzip_file_to_dir',
 ]
 
+from tempfile import TemporaryDirectory
 import contextlib
 from os import getcwd, chdir
 import os.path
@@ -24,16 +25,23 @@ def abspath(url):
     return os.path.abspath(url)
 
 @contextlib.contextmanager
-def pushd_popd(newcwd=None):
+def pushd_popd(newcwd=None, tempdir=False):
+    if newcwd and tempdir:
+        raise Exception("pushd_popd can accept either newcwd or tempdir, not both")
     try:
         oldcwd = getcwd()
     except FileNotFoundError as e:  # pylint: disable=unused-variable
         # This happens when a directory is deleted before the context is exited
         oldcwd = '/tmp'
     try:
-        if newcwd:
-            chdir(newcwd)
-        yield
+        if tempdir:
+            with TemporaryDirectory() as tempcwd:
+                chdir(tempcwd)
+                yield tempcwd
+        else:
+            if newcwd:
+                chdir(newcwd)
+            yield newcwd
     finally:
         chdir(oldcwd)
 
